==> owncloud_6.0.4~beta1%2Bdfsg.orig.tar.bz2: owncloud/core/l10n/fr.php <==
<?php
$TRANSLATIONS = array(
"%s shared »%s« with you" => "%s partagé »%s« avec vous",
"Couldn't send mail to following users: %s " => "Impossible d'envoyer un mail aux utilisateurs suivant : %s",
"Turned on maintenance mode" => "Basculé en mode maintenance",
"Turned off maintenance mode" => "Basculé en mode production (non maintenance)",
"Updated database" => "Base de données mise à jour",
"Updating filecache, this may take really long..." => "En cours de mise à jour de cache de fichiers. Cette opération peut être très longue...",
"Updated filecache" => "Cache de fichier mis à jour",
"... %d%% done ..." => "... %d%% effectué ...",
"No image or file provided" => "Aucune image ou fichier fourni",
"Unknown filetype" => "Type de fichier inconnu",
"Invalid image" => "Image invalide",
"No temporary profile picture available, try again" => "Aucune image temporaire disponible pour le profil. Essayez à nouveau.",
"No crop data provided" => "Aucune donnée de culture fournie",
"Sunday" => "Dimanche",
"Monday" => "Lundi",
"Tuesday" => "Mardi",
"Wednesday" => "Mercredi",
"Thursday" => "Jeudi",
"Friday" => "Vendredi",
"Saturday" => "Samedi",
"January" => "janvier",
"February" => "février",
"March" => "mars",
"April" => "avril",
"May" => "mai",
"June" => "juin",
"July" => "juillet",
"August" => "août",
"September" => "septembre",
"October" => "octobre",
"November" => "novembre",
"December" => "décembre",
"Settings" => "Paramètres",
"seconds ago" => "il y a quelques secondes",
"_%n minute ago_::_%n minutes ago_" => array("il y a %n minute","il y a %n minutes"),
"_%n hour ago_::_%n hours ago_" => array("Il y a %n heure","Il y a %n heures"),
"today" => "aujourd'hui",
"yesterday" => "hier",
"_%n day ago_::_%n days ago_" => array("il y a %n jour","il y a %n jours"),
"last month" => "le mois dernier",
"_%n month ago_::_%n months ago_" => array("Il y a %n mois","Il y a %n mois"),
"months ago" => "il y a plusieurs mois",
"last year" => "l'année dernière",
"years ago" => "il y a plusieurs années",
"Choose" => "Choisir",
"Error loading file picker template: {error}" => "Erreur de chargement du modèle de sélectionneur de fichiers : {error}",
"Yes" => "Oui",
"No" => "Non",
"Ok" => "Ok",
"Error loading message template: {error}" => "Erreur de chargement du modèle de message : {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} fichier en conflit","{count} fichiers en conflit"),
"One file conflict" => "Un conflit de fichier",
"Which files do you want to keep?" => "Quels fichiers désirez-vous garder ?",
"If you select both versions, the copied file will have a number added to its name." => "Si vous sélectionnez les deux versions, un nombre sera ajouté au nom du fichier copié.",
"Cancel" => "Annuler",
"Continue" => "Poursuivre",
"(all selected)" => "(tous sélectionnés)",
"({count} selected)" => "({count} sélectionnés)",
"Error loading file exists template" => "Erreur de chargement du modèle de fichier existant",
"Shared" => "Partagé",
"Share" => "Partager",
"Error" => "Erreur",
"Error while sharing" => "Erreur lors de la mise en partage",
"Error while unsharing" => "Erreur lors de l'annulation du partage",
"Error while changing permissions" => "Erreur lors du changement des permissions",
"Shared with you and the group {group} by {owner}" => "Partagé par {owner} avec vous et le groupe {group}",
"Shared with you by {owner}" => "Partagé avec vous par {owner}",
"Share with user or group …" => "Partager avec un utilisateur ou un groupe...",
"Share link" => "Partager le lien",
"Password protect" => "Protéger par un mot de passe",
"Password" => "Mot de passe",
"Allow Public Upload" => "Autoriser l'upload par les utilisateurs non enregistrés",
"Email link to person" => "Envoyez le lien par email",
"Send" => "Envoyer",
"Set expiration date" => "Spécifier la date d'expiration",
"Expiration date" => "Date d'expiration",
"Share via email:" => "Partager via e-mail :",
"No people found" => "Aucun utilisateur trouvé",
"group" => "groupe",
"Resharing is not allowed" => "Le repartage n'est pas autorisé",
"Shared in {item} with {user}" => "Partagé dans {item} avec {user}",
"Unshare" => "Ne plus partager",
"notify by email" => "Notifier par email",
"can edit" => "édition autorisée",
"access control" => "contrôle des accès",
"create" => "créer",
"update" => "mettre à jour",
"delete" => "supprimer",
"share" => "partager",
"Password protected" => "Protégé par un mot de passe",
"Error unsetting expiration date" => "Une erreur est survenue pendant la suppression de la date d'expiration",
"Error setting expiration date" => "Erreur lors de la spécification de la date d'expiration",
"Sending ..." => "En cours d'envoi ...",
"Email sent" => "Email envoyé",
"Warning" => "Attention",
"The object type is not specified." => "Le type d'objet n'est pas spécifié.",
"Enter new" => "Saisir un nouveau",
"Delete" => "Supprimer",
"Add" => "Ajouter",
"Edit tags" => "Modifier les balises",
"Error loading dialog template: {error}" => "Erreur de chargement du modèle de dialogue : {error}",
"No tags selected for deletion." => "Aucune balise sélectionnée pour la suppression.",
"Please reload the page." => "Veuillez recharger la page.",
"The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." => "La mise à jour a échoué. Veuillez signaler ce problème à la <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">communauté ownCloud</a>.",
"The update was successful. Redirecting you to ownCloud now." => "La mise à jour a réussi. Vous êtes redirigé maintenant vers ownCloud.",
"%s password reset" => "Réinitialisation de votre mot de passe %s",
"Use the following link to reset your password: {link}" => "Utilisez le lien suivant pour réinitialiser votre mot de passe : {link}",
"The link to reset your password has been sent to your email.<br>If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator ." => "Le lien permettant de réinitialiser votre mot de passe vous a été transmis.<br>Si vous ne le recevez pas dans un délai raisonnable, vérifier votre boîte de pourriels.<br>Au besoin, contactez votre administrateur local.",
"Request failed!<br>Did you make sure your email/username was right?" => "Requête en échec!<br>Avez-vous vérifié vos courriel/nom d'utilisateur?",
"You will receive a link to reset your password via Email." => "Vous allez recevoir un e-mail contenant un lien pour réinitialiser votre mot de passe.",
"Username" => "Nom d'utilisateur",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" => "Vos fichiers sont chiffrés. Si vous n'avez pas activé la clef de récupération, il n'y aura plus aucun moyen de récupérer vos données une fois le mot de passe réinitialisé. Si vous n'êtes pas sûr de ce que vous faites, veuillez contacter votre administrateur avant de continuer. Voulez-vous vraiment continuer ?",
"Yes, I really want to reset my password now" => "Oui, je veux vraiment réinitialiser mon mot de passe maintenant",
"Reset" => "Réinitialiser",
"Your password was reset" => "Votre mot de passe a été réinitialisé",
"To login page" => "Retour à la page d'authentification",
"New password" => "Nouveau mot de passe",
"Reset password" => "Réinitialiser le mot de passe",
"Personal" => "Personnel",
"Users" => "Utilisateurs",
"Apps" => "Applications",
"Admin" => "Administration",
"Help" => "Aide",
"Error loading tags" => "Erreur de chargement des balises.",
"Tag already exists" => "La balise existe déjà.",
"Error deleting tag(s)" => "Erreur de suppression de(s) balise(s)",
"Error tagging" => "Erreur lors de la mise en place de la balise",
"Error untagging" => "Erreur lors de la suppression de la balise",
"Error favoriting" => "Erreur lors de la mise en favori",
"Error unfavoriting" => "Erreur lors de la suppression des favoris",
"Access forbidden" => "Accès interdit",
"Cloud not found" => "Introuvable",
"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "Bonjour,\n\nNous vous informons que %s a partagé %s avec vous.\nConsultez-le : %s\n",
"The share will expire on %s." => "Le partage expirera le %s.",
"Cheers!" => "À bientôt !",
"Security Warning" => "Avertissement de sécurité",
"Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" => "Votre version de PHP est vulnérable à l'attaque par caractère NULL (CVE-2006-7243)",
"Please update your PHP installation to use %s securely." => "Veuillez mettre à jour votre installation PHP pour utiliser %s de façon sécurisée.",
"No secure random number generator is available, please enable the PHP OpenSSL extension." => "Aucun générateur de nombre aléatoire sécurisé n'est disponible, veuillez activer l'extension PHP OpenSSL",
"Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account." => "Sans générateur de nombre aléatoire sécurisé, un attaquant peut être en mesure de prédire les jetons de réinitialisation du mot de passe, et ainsi prendre le contrôle de votre compte utilisateur.",
"Your data directory and files are probably accessible from the internet because the .htaccess file does not work." => "Votre répertoire data est certainement accessible depuis l'internet car le fichier .htaccess ne semble pas fonctionner",
"For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." => "Pour les informations de configuration de votre serveur, veuillez lire la <a href=\"%s\" target=\"_blank\">documentation</a>.",
"Create an <strong>admin account</strong>" => "Créer un <strong>compte administrateur</strong>",
"Advanced" => "Avancé",
"Data folder" => "Répertoire des données",
"Configure the database" => "Configurer la base de données",
"will be used" => "sera utilisé",
"Database user" => "Utilisateur pour la base de données",
"Database password" => "Mot de passe de la base de données",
"Database name" => "Nom de la base de données",
"Database tablespace" => "Tablespaces de la base de données",
"Database host" => "Serveur de la base de données",
"Finish setup" => "Terminer l'installation",
"Finishing …" => "En cours de finalisation...",
"%s is available. Get more information on how to update." => "%s est disponible. Obtenez plus d'informations sur la façon de mettre à jour.",
"Log out" => "Se déconnecter",
"Automatic logon rejected!" => "Connexion automatique rejetée !",
"If you did not change your password recently, your account may be compromised!" => "Si vous n'avez pas changé votre mot de passe récemment, votre compte risque d'être compromis !",
"Please change your password to secure your account again." => "Veuillez changer votre mot de passe pour sécuriser à nouveau votre compte.",
"Server side authentication failed!" => "L'authentification côté serveur a échoué !",
"Please contact your administrator." => "Veuillez contacter votre administrateur.",
"Lost your password?" => "Mot de passe perdu ?",
"remember" => "se souvenir de moi",
"Log in" => "Connexion",
"Alternative Logins" => "Logins alternatifs",
"Hey there,<br><br>just letting you know that %s shared »%s« with you.<br><a href=\"%s\">View it!</a><br><br>" => "Bonjour,<br><br>Nous vous informons que %s a partagé »%s« avec vous.<br><a href=\"%s\">Consultez-le !</a><br><br>",
"This ownCloud instance is currently in single user mode." => "Cette instance de ownCloud est actuellement en mode utilisateur unique.",
"This means only administrators can use the instance." => "Cela signifie que uniquement les administrateurs peuvent utiliser l'instance.",
"Contact your system administrator if this message persists or appeared unexpectedly." => "Contactez votre administrateur système si ce message persiste ou apparaît de façon innatendue.",
"Thank you for your patience." => "Merci de votre patience.",
"Updating ownCloud to version %s, this may take a while." => "Mise à jour en cours d'ownCloud vers la version %s, cela peut prendre du temps.",
"This ownCloud instance is currently being updated, which may take a while." => "Cette instance d'ownCloud est en cours de mise à jour, cela peut prendre du temps.",
"Please reload this page after a short time to continue using ownCloud." => "Merci de recharger cette page après un moment pour continuer à utiliser ownCloud."
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";

==> owncloud_7.0.0~beta1%2Bdfsg.orig.tar.bz2: owncloud/core/l10n/fr.php <==
<?php
$TRANSLATIONS = array(
"Expiration date is in the past." => "La date d'expiration est dans le passé.",
"Couldn't send mail to following users: %s " => "Impossible d'envoyer un mail aux utilisateurs suivant : %s",
"Turned on maintenance mode" => "Basculé en mode maintenance",
"Turned off maintenance mode" => "Basculé en mode production (non maintenance)",
"Updated database" => "Base de données mise à jour",
"Checked database schema update" => "Mise à jour du schéma de la base de données vérifiée",
"Disabled incompatible apps: %s" => "Applications incompatibles désactivées: %s",
"No image or file provided" => "Aucune image ou fichier fourni",
"Unknown filetype" => "Type de fichier inconnu",
"Invalid image" => "Image invalide",
"No temporary profile picture available, try again" => "Aucune image temporaire disponible pour le profil. Essayez à nouveau.",
"No crop data provided" => "Aucune donnée de culture fournie",
"Sunday" => "Dimanche",
"Monday" => "Lundi",
"Tuesday" => "Mardi",
"Wednesday" => "Mercredi",
"Thursday" => "Jeudi",
"Friday" => "Vendredi",
"Saturday" => "Samedi",
"January" => "janvier",
"February" => "février",
"March" => "mars",
"April" => "avril",
"May" => "mai",
"June" => "juin",
"July" => "juillet",
"August" => "août",
"September" => "septembre",
"October" => "octobre",
"November" => "novembre",
"December" => "décembre",
"Settings" => "Paramètres",
"File" => "Fichier",
"Folder" => "Dossier",
"Image" => "Image",
"Audio" => "Audio",
"Saving..." => "Enregistrement...",
"seconds ago" => "il y a quelques secondes",
"_%n minute ago_::_%n minutes ago_" => array("il y a %n minute","il y a %n minutes"),
"_%n hour ago_::_%n hours ago_" => array("Il y a %n heure","Il y a %n heures"),
"today" => "aujourd'hui",
"yesterday" => "hier",
"_%n day ago_::_%n days ago_" => array("il y a %n jour","il y a %n jours"),
"last month" => "le mois dernier",
"_%n month ago_::_%n months ago_" => array("Il y a %n mois","Il y a %n mois"),
"last year" => "l'année dernière",
"years ago" => "il y a plusieurs années",
"Couldn't send reset email. Please contact your administrator." => "Impossible d'envoyer l’émail de réinitialisation. Veuillez contacter votre administrateur.",
"The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." => "Le lien permettant de réinitialiser votre mot de passe vous a été transmis à votre adresse email.<br>Si vous ne le recevez pas dans un délai raisonnable, vérifier votre boîte de pourriels.<br>Au besoin, contactez votre administrateur local.",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" => "Vos fichiers sont chiffrés. Si vous n'avez pas activé la clef de récupération, il n'y aura plus aucun moyen de récupérer vos données une fois le mot de passe réinitialisé. Si vous n'êtes pas sûr de ce que vous faites, veuillez contacter votre administrateur avant de continuer. Voulez-vous vraiment continuer ?",
"I know what I'm doing" => "Je sais ce que je fais",
"Reset password" => "Réinitialiser le mot de passe",
"Password can not be changed. Please contact your administrator." => "Le mot de passe ne peut être modifié. Veuillez contacter votre administrateur.",
"Yes" => "Oui",
"No" => "Non",
"Choose" => "Choisir",
"Error loading file picker template: {error}" => "Erreur de chargement du modèle de sélectionneur de fichiers : {error}",
"Ok" => "Ok",
"Error loading message template: {error}" => "Erreur de chargement du modèle de message : {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} fichier en conflit","{count} fichiers en conflit"),
"One file conflict" => "Un conflit de fichier",
"New Files" => "Nouveaux fichiers",
"Already existing files" => "Fichiers déjà existants",
"Which files do you want to keep?" => "Quels fichiers désirez-vous garder ?",
"If you select both versions, the copied file will have a number added to its name." => "Si vous sélectionnez les deux versions, un nombre sera ajouté au nom du fichier copié.",
"Cancel" => "Annuler",
"Continue" => "Poursuivre",
"(all selected)" => "(tous sélectionnés)",
"({count} selected)" => "({count} sélectionnés)",
"Error loading file exists template" => "Erreur de chargement du modèle de fichier existant",
"Very weak password" => "Mot de passe de très faible sécurité",
"Weak password" => "Mot de passe de faible sécurité",
"So-so password" => "Mot de passe de sécurité tout juste acceptable",
"Good password" => "Mot de passe de sécurité suffisante",
"Strong password" => "Mot de passe de forte sécurité",
"Shared" => "Partagé",
"Shared by {owner}" => "Partagé par {owner}",
"Shared with {recipients}" => "Partagé avec {recipients}",
"Share" => "Partager",
"Error" => "Erreur",
"Error while sharing" => "Erreur lors de la mise en partage",
"Error while unsharing" => "Erreur lors de l'annulation du partage",
"Error while changing permissions" => "Erreur lors du changement des permissions",
"Shared with you and the group {group} by {owner}" => "Partagé par {owner} avec vous et le groupe {group}",
"Shared with you by {owner}" => "Partagé avec vous par {owner}",
"Share with user or group …" => "Partager avec un utilisateur ou un groupe...",
"Share link" => "Partager le lien",
"The public link will expire no later than {days} days after it is created" => "Ce lien public expirera au plus tard, dans {days} jours après sa création.",
"By default the public link will expire after {days} days" => "Par défaut, le lien public expire après {days} jour(s).",
"Password protect" => "Protéger par un mot de passe",
"Choose a password for the public link" => "Choisissez un mot de passe pour le lien public.",
"Allow Public Upload" => "Autoriser l'upload par les utilisateurs non enregistrés",
"Email link to person" => "Envoyez le lien par email",
"Send" => "Envoyer",
"Set expiration date" => "Spécifier la date d'expiration",
"Expiration date" => "Date d'expiration",
"Share via email:" => "Partager via e-mail :",
"No people found" => "Aucun utilisateur trouvé",
"group" => "groupe",
"Resharing is not allowed" => "Le repartage n'est pas autorisé",
"Shared in {item} with {user}" => "Partagé dans {item} avec {user}",
"Unshare" => "Ne plus partager",
"notify by email" => "Notifier par email",
"can edit" => "édition autorisée",
"access control" => "contrôle des accès",
"create" => "créer",
"update" => "mettre à jour",
"delete" => "supprimer",
"share" => "partager",
"Password protected" => "Protégé par un mot de passe",
"Error unsetting expiration date" => "Une erreur est survenue pendant la suppression de la date d'expiration",
"Error setting expiration date" => "Erreur lors de la spécification de la date d'expiration",
"Sending ..." => "En cours d'envoi ...",
"Email sent" => "Email envoyé",
"Warning" => "Attention",
"The object type is not specified." => "Le type d'objet n'est pas spécifié.",
"Enter new" => "Saisir un nouveau",
"Delete" => "Supprimer",
"Add" => "Ajouter",
"Edit tags" => "Modifier les balises",
"Error loading dialog template: {error}" => "Erreur de chargement du modèle de dialogue : {error}",
"No tags selected for deletion." => "Aucune balise sélectionnée pour la suppression.",
"Updating {productName} to version {version}, this may take a while." => "Mise à jour en cours de {productName} vers la version {version}, cela peut prendre du temps.",
"Please reload the page." => "Veuillez recharger la page.",
"The update was unsuccessful." => "La mise à jour a échoué.",
"The update was successful. Redirecting you to ownCloud now." => "La mise à jour a réussi. Vous êtes redirigé maintenant vers ownCloud.",
"Couldn't reset password because the token is invalid" => "Impossible de réinitialiser le mot de passe car le jeton est invalide.",
"Couldn't send reset email. Please make sure your username is correct." => "Impossible d'envoyer l’émail de réinitialisation. Veuillez vérifier que votre nom d'utilisateur est correct.",
"Couldn't send reset email because there is no email address for this username. Please contact your administrator." => "Impossible d'envoyer l'email de réinitialisation car il n'y a aucune adresse email pour cet utilisateur. Veuillez contacter votre administrateur.",
"%s password reset" => "Réinitialisation de votre mot de passe %s",
"Use the following link to reset your password: {link}" => "Utilisez le lien suivant pour réinitialiser votre mot de passe : {link}",
"You will receive a link to reset your password via Email." => "Vous allez recevoir un e-mail contenant un lien pour réinitialiser votre mot de passe.",
"Username" => "Nom d'utilisateur",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" => "Vos fichiers sont chiffrés. Si vous n'avez pas activé la clef de récupération, il n'y aura plus aucun moyen de récupérer vos données une fois le mot de passe réinitialisé. Si vous n'êtes pas sûr de ce que vous faites, veuillez contacter votre administrateur avant de continuer. Voulez-vous vraiment continuer ?",
"Yes, I really want to reset my password now" => "Oui, je veux vraiment réinitialiser mon mot de passe maintenant",
"Reset" => "Réinitialiser",
"New password" => "Nouveau mot de passe",
"New Password" => "Nouveau mot de passe",
"Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " => "Mac OS X n'est pas supporté et %s ne fonctionnera pas correctement sur cette plateforme. Son utilisation est à vos risques et périls !",
"For the best results, please consider using a GNU/Linux server instead." => "Pour des résultats meilleurs encore, pensez à utiliser un serveur GNU/Linux à la place.",
"Personal" => "Personnel",
"Users" => "Utilisateurs",
"Apps" => "Applications",
"Admin" => "Administration",
"Help" => "Aide",
"Error loading tags" => "Erreur de chargement des balises.",
"Tag already exists" => "La balise existe déjà.",
"Error deleting tag(s)" => "Erreur de suppression de(s) balise(s)",
"Error tagging" => "Erreur lors de la mise en place de la balise",
"Error untagging" => "Erreur lors de la suppression de la balise",
"Error favoriting" => "Erreur lors de la mise en favori",
"Error unfavoriting" => "Erreur lors de la suppression des favoris",
"Access forbidden" => "Accès interdit",
"Cloud not found" => "Introuvable",
"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "Bonjour,\n\nNous vous informons que %s a partagé %s avec vous.\nConsultez-le : %s\n",
"The share will expire on %s." => "Le partage expirera le %s.",
"Cheers!" => "À bientôt !",
"Security Warning" => "Avertissement de sécurité",
"Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" => "Votre version de PHP est vulnérable à l'attaque par caractère NULL (CVE-2006-7243)",
"Please update your PHP installation to use %s securely." => "Veuillez mettre à jour votre installation PHP pour utiliser %s de façon sécurisée.",
"No secure random number generator is available, please enable the PHP OpenSSL extension." => "Aucun générateur de nombre aléatoire sécurisé n'est disponible, veuillez activer l'extension PHP OpenSSL",
"Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account." => "Sans générateur de nombre aléatoire sécurisé, un attaquant peut être en mesure de prédire les jetons de réinitialisation du mot de passe, et ainsi prendre le contrôle de votre compte utilisateur.",
"Your data directory and files are probably accessible from the internet because the .htaccess file does not work." => "Votre répertoire data est certainement accessible depuis l'internet car le fichier .htaccess ne semble pas fonctionner",
"For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." => "Pour les informations de configuration de votre serveur, veuillez lire la <a href=\"%s\" target=\"_blank\">documentation</a>.",
"Create an <strong>admin account</strong>" => "Créer un <strong>compte administrateur</strong>",
"Password" => "Mot de passe",
"Storage & database" => "Support de stockage & base de données",
"Data folder" => "Répertoire des données",
"Configure the database" => "Configurer la base de données",
"Only %s is available." => "%s disponible uniquement.",
"Database user" => "Utilisateur pour la base de données",
"Database password" => "Mot de passe de la base de données",
"Database name" => "Nom de la base de données",
"Database tablespace" => "Tablespaces de la base de données",
"Database host" => "Serveur de la base de données",
"SQLite will be used as database. For larger installations we recommend to change this." => "SQLite va être utilisée comme base de donnée. Pour des installations plus volumineuse, nous vous conseillons de changer ce réglage.",
"Finish setup" => "Terminer l'installation",
"Finishing …" => "En cours de finalisation...",
"This application requires JavaScript to be enabled for correct operation.  Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and re-load this interface." => "Cette application nécessite que JavaScript soit activé pour fonctionner correctement.  Veuillez <a href=\"http://enable-javascript.com/\" target=\"_blank\">activer JavaScript</a> puis charger à nouveau cette interface.",
"%s is available. Get more information on how to update." => "%s est disponible. Obtenez plus d'informations sur la façon de mettre à jour.",
"Log out" => "Se déconnecter",
"Automatic logon rejected!" => "Connexion automatique rejetée !",
"If you did not change your password recently, your account may be compromised!" => "Si vous n'avez pas changé votre mot de passe récemment, votre compte risque d'être compromis !",
"Please change your password to secure your account again." => "Veuillez changer votre mot de passe pour sécuriser à nouveau votre compte.",
"Server side authentication failed!" => "L'authentification côté serveur a échoué !",
"Please contact your administrator." => "Veuillez contacter votre administrateur.",
"Forgot your password? Reset it!" => "Mot de passe perdu ? Réinitialisez-le !",
"remember" => "se souvenir de moi",
"Log in" => "Connexion",
"Alternative Logins" => "Logins alternatifs",
"Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" => "Bonjour,<br><br>Juste pour vous informer que %s a partagé <strong>%s</strong> avec vous.<br><a href=\"%s\">Consultez-le !</a><br><br>",
"This ownCloud instance is currently in single user mode." => "Cette instance de ownCloud est actuellement en mode utilisateur unique.",
"This means only administrators can use the instance." => "Cela signifie que uniquement les administrateurs peuvent utiliser l'instance.",
"Contact your system administrator if this message persists or appeared unexpectedly." => "Contactez votre administrateur système si ce message persiste ou apparaît de façon innatendue.",
"Thank you for your patience." => "Merci de votre patience.",
"%s will be updated to version %s." => "%s sera mis à jour vers la version %s.",
"The following apps will be disabled:" => "Les applications suivantes seront désactivées :",
"The theme %s has been disabled." => "Le thème %s a été désactivé.",
"Please make sure that the database, the config folder and the data folder have been backed up before proceeding." => "Veuillez vous assurer qu'une copie de sauvegarde de la base de données, du dossier de configuration et du dossier de données a été réalisée avant le commencement de la procédure.",
"Start update" => "Démarrer la mise à jour.",
"This ownCloud instance is currently being updated, which may take a while." => "Cette instance d'ownCloud est en cours de mise à jour, cela peut prendre du temps.",
"Please reload this page after a short time to continue using ownCloud." => "Merci de recharger cette page après un moment pour continuer à utiliser ownCloud."
);
$PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
